# financial-reports-generated-client
Welcome to the Financial Reports API, your gateway to European company filings, financial data, and corporate information. All API requests must be authenticated. Authentication is performed by including your unique API key in the **X-API-Key** HTTP header. Please use the \"Authorize\" button to set your key and try out the endpoints.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.3.6
- Generator version: 7.18.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://financialreports.eu/](https://financialreports.eu/)

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import financial_reports_generated_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import financial_reports_generated_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import financial_reports_generated_client
from financial_reports_generated_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.financialreports.eu
# See configuration.py for a list of all supported configuration parameters.
configuration = financial_reports_generated_client.Configuration(
    host = "https://api.financialreports.eu"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKeyAuth
configuration.api_key['ApiKeyAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKeyAuth'] = 'Bearer'


# Enter a context with an instance of the API client
async with financial_reports_generated_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = financial_reports_generated_client.CompaniesApi(api_client)
    countries = 'countries_example' # str | Filter by Company country ISO Alpha-2 code(s). Comma-separated for multiple values. (optional)
    industry = 'industry_example' # str | Filter by ISIC Group code. (optional)
    industry_group = 'industry_group_example' # str | Filter by ISIC Division code. (optional)
    isin = 'isin_example' # str | Filter by Company ISIN. Case-insensitive. (optional)
    lei = 'lei_example' # str | Filter by Company Legal Entity Identifier (LEI). Case-insensitive. (optional)
    on_watchlist = True # bool | Filter by companies on the user's watchlist. Use 'true' to see only watchlist companies, 'false' to exclude them. Omitting the parameter returns all companies. (optional)
    ordering = 'ordering_example' # str | Which field to use when ordering the results. Available fields: `id`, `name`, `date_ipo`, `year_founded`, `country_iso__name`. Prefix with '-' for descending order (e.g., `-name`). (optional)
    page = 56 # int | A page number within the paginated result set. (optional)
    page_size = 56 # int | Number of results to return per page. (optional)
    search = 'search_example' # str | A search term. (optional)
    sector = 'sector_example' # str | Filter by ISIC Section code. (optional)
    sub_industry = 'sub_industry_example' # str | Filter by ISIC Class code. (optional)
    ticker = 'ticker_example' # str | Filter by Company primary stock Ticker symbol. Case-insensitive. (optional)
    view = summary # str | Controls the level of detail. Omit for a default 'summary' view, or use 'full' to include all details for each company. (optional) (default to summary)

    try:
        # List Companies
        api_response = await api_instance.companies_list(countries=countries, industry=industry, industry_group=industry_group, isin=isin, lei=lei, on_watchlist=on_watchlist, ordering=ordering, page=page, page_size=page_size, search=search, sector=sector, sub_industry=sub_industry, ticker=ticker, view=view)
        print("The response of CompaniesApi->companies_list:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling CompaniesApi->companies_list: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.financialreports.eu*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CompaniesApi* | [**companies_list**](docs/CompaniesApi.md#companies_list) | **GET** /companies/ | List Companies
*CompaniesApi* | [**companies_retrieve**](docs/CompaniesApi.md#companies_retrieve) | **GET** /companies/{id}/ | Retrieve Company Details
*CountriesApi* | [**countries_list**](docs/CountriesApi.md#countries_list) | **GET** /countries/ | List Countries
*CountriesApi* | [**countries_retrieve**](docs/CountriesApi.md#countries_retrieve) | **GET** /countries/{id}/ | Retrieve Country
*FilingTypesApi* | [**filing_types_list**](docs/FilingTypesApi.md#filing_types_list) | **GET** /filing-types/ | List Filing Types
*FilingTypesApi* | [**filing_types_retrieve**](docs/FilingTypesApi.md#filing_types_retrieve) | **GET** /filing-types/{id}/ | Retrieve Filing Type
*FilingsApi* | [**filings_list**](docs/FilingsApi.md#filings_list) | **GET** /filings/ | List Filings
*FilingsApi* | [**filings_markdown_retrieve**](docs/FilingsApi.md#filings_markdown_retrieve) | **GET** /filings/{filing_id}/markdown/ | Retrieve Filing Markdown
*FilingsApi* | [**filings_retrieve**](docs/FilingsApi.md#filings_retrieve) | **GET** /filings/{id}/ | Retrieve Filing Details
*ISICClassificationsApi* | [**isic_classes_list**](docs/ISICClassificationsApi.md#isic_classes_list) | **GET** /isic-classes/ | List ISIC Classes
*ISICClassificationsApi* | [**isic_classes_retrieve**](docs/ISICClassificationsApi.md#isic_classes_retrieve) | **GET** /isic-classes/{id}/ | Retrieve ISIC Class
*ISICClassificationsApi* | [**isic_divisions_list**](docs/ISICClassificationsApi.md#isic_divisions_list) | **GET** /isic-divisions/ | List ISIC Divisions
*ISICClassificationsApi* | [**isic_divisions_retrieve**](docs/ISICClassificationsApi.md#isic_divisions_retrieve) | **GET** /isic-divisions/{id}/ | Retrieve ISIC Division
*ISICClassificationsApi* | [**isic_groups_list**](docs/ISICClassificationsApi.md#isic_groups_list) | **GET** /isic-groups/ | List ISIC Groups
*ISICClassificationsApi* | [**isic_groups_retrieve**](docs/ISICClassificationsApi.md#isic_groups_retrieve) | **GET** /isic-groups/{id}/ | Retrieve ISIC Group
*ISICClassificationsApi* | [**isic_sections_list**](docs/ISICClassificationsApi.md#isic_sections_list) | **GET** /isic-sections/ | List ISIC Sections
*ISICClassificationsApi* | [**isic_sections_retrieve**](docs/ISICClassificationsApi.md#isic_sections_retrieve) | **GET** /isic-sections/{id}/ | Retrieve ISIC Section
*LanguagesApi* | [**languages_list**](docs/LanguagesApi.md#languages_list) | **GET** /languages/ | List Languages
*LanguagesApi* | [**languages_retrieve**](docs/LanguagesApi.md#languages_retrieve) | **GET** /languages/{id}/ | Retrieve Language
*SourcesApi* | [**sources_list**](docs/SourcesApi.md#sources_list) | **GET** /sources/ | List Data Sources
*SourcesApi* | [**sources_retrieve**](docs/SourcesApi.md#sources_retrieve) | **GET** /sources/{id}/ | Retrieve Data Source
*WatchlistApi* | [**watchlist_companies_create**](docs/WatchlistApi.md#watchlist_companies_create) | **POST** /watchlist/companies/ | Add Company to Watchlist
*WatchlistApi* | [**watchlist_companies_destroy**](docs/WatchlistApi.md#watchlist_companies_destroy) | **DELETE** /watchlist/companies/{company_id}/ | Remove Company from Watchlist
*WatchlistApi* | [**watchlist_retrieve**](docs/WatchlistApi.md#watchlist_retrieve) | **GET** /watchlist/ | Get User&#39;s Watchlist
*WebhooksManagementApi* | [**webhooks_create**](docs/WebhooksManagementApi.md#webhooks_create) | **POST** /webhooks/ | Create Webhook
*WebhooksManagementApi* | [**webhooks_destroy**](docs/WebhooksManagementApi.md#webhooks_destroy) | **DELETE** /webhooks/{id}/ | Delete Webhook
*WebhooksManagementApi* | [**webhooks_list**](docs/WebhooksManagementApi.md#webhooks_list) | **GET** /webhooks/ | List Webhooks
*WebhooksManagementApi* | [**webhooks_partial_update**](docs/WebhooksManagementApi.md#webhooks_partial_update) | **PATCH** /webhooks/{id}/ | Partial Update Webhook
*WebhooksManagementApi* | [**webhooks_regenerate_secret_create**](docs/WebhooksManagementApi.md#webhooks_regenerate_secret_create) | **POST** /webhooks/{id}/regenerate-secret/ | Regenerate Secret Key
*WebhooksManagementApi* | [**webhooks_retrieve**](docs/WebhooksManagementApi.md#webhooks_retrieve) | **GET** /webhooks/{id}/ | Retrieve Webhook
*WebhooksManagementApi* | [**webhooks_test_create**](docs/WebhooksManagementApi.md#webhooks_test_create) | **POST** /webhooks/{id}/test/ | Test Webhook
*WebhooksManagementApi* | [**webhooks_update**](docs/WebhooksManagementApi.md#webhooks_update) | **PUT** /webhooks/{id}/ | Update Webhook


## Documentation For Models

 - [Company](docs/Company.md)
 - [CompanyMinimal](docs/CompanyMinimal.md)
 - [Country](docs/Country.md)
 - [DesignatedSponsor](docs/DesignatedSponsor.md)
 - [ErrorDetail](docs/ErrorDetail.md)
 - [Filing](docs/Filing.md)
 - [FilingProcessedPayload](docs/FilingProcessedPayload.md)
 - [FilingSummary](docs/FilingSummary.md)
 - [FilingType](docs/FilingType.md)
 - [ISICClass](docs/ISICClass.md)
 - [ISICDivision](docs/ISICDivision.md)
 - [ISICGroup](docs/ISICGroup.md)
 - [ISICSection](docs/ISICSection.md)
 - [Language](docs/Language.md)
 - [ListedStockExchange](docs/ListedStockExchange.md)
 - [PaginatedCompanyMinimalList](docs/PaginatedCompanyMinimalList.md)
 - [PaginatedCountryList](docs/PaginatedCountryList.md)
 - [PaginatedFilingSummaryList](docs/PaginatedFilingSummaryList.md)
 - [PaginatedFilingTypeList](docs/PaginatedFilingTypeList.md)
 - [PaginatedISICClassList](docs/PaginatedISICClassList.md)
 - [PaginatedISICDivisionList](docs/PaginatedISICDivisionList.md)
 - [PaginatedISICGroupList](docs/PaginatedISICGroupList.md)
 - [PaginatedISICSectionList](docs/PaginatedISICSectionList.md)
 - [PaginatedLanguageList](docs/PaginatedLanguageList.md)
 - [PaginatedSourceList](docs/PaginatedSourceList.md)
 - [PaginatedWebhookList](docs/PaginatedWebhookList.md)
 - [PatchedWebhook](docs/PatchedWebhook.md)
 - [Source](docs/Source.md)
 - [StockIndex](docs/StockIndex.md)
 - [WatchlistAction](docs/WatchlistAction.md)
 - [WatchlistCompany](docs/WatchlistCompany.md)
 - [WatchlistResponse](docs/WatchlistResponse.md)
 - [Webhook](docs/Webhook.md)
 - [WebhookCompanyPayload](docs/WebhookCompanyPayload.md)
 - [WebhookFilingPayload](docs/WebhookFilingPayload.md)
 - [WebhookRegenerateSecret](docs/WebhookRegenerateSecret.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ApiKeyAuth"></a>
### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-Key
- **Location**: HTTP header


## Author

api@financialreports.eu


